library(shiny)
library(esquisse)

options(shiny.maxRequestSize = 30*1024^2)
options("esquisse.coerceVars" = TRUE)

ui <- fluidPage(
  
  titlePanel("ggplot helper whith esquisse package as a Shiny module"),
  
  sidebarLayout(
    sidebarPanel(width = 2,
      radioButtons(
        inputId = "data", 
        label = "Data to use:", 
        choices = c("Load New data","iris", "mtcars"),
        inline = TRUE
      ),
      chooseDataUI("datafile")
    ),
    mainPanel(width = 10,
      tabsetPanel(
        tabPanel(
          title = "esquisse",
          esquisserUI(
            id = "esquisse", 
            header = FALSE, # dont display gadget title
            choose_data = FALSE, # dont display button to change data
            container = esquisseContainer(height = "1200px")
          )
        ),
        tabPanel(
          title = "output",
          verbatimTextOutput("module_out")
        )
      )
    )
  )
)


server <- function(input, output, session) {
  
  data_r <- reactiveValues(data = data.frame(), name = "default")
  data_file <- callModule(module = chooseDataServer, id= "datafile", dataModule = "ImportFile", name="imported", coerceVars = TRUE)
  data_r = isolate(data_file)
  

  observeEvent(input$data, {
    if (input$data == "iris") {
      data_r$data <- iris
      data_r$name <- "iris"
    } else if (input$data == "mtcars") {
      data_r$data <- mtcars
      data_r$name <- "mtcars"
    } else {
       
    data_file <- callModule(module = chooseDataServer, id= "datafile", dataModule = "ImportFile", name="imported", coerceVars = TRUE)
    data_r = isolate(data_file)
    
    }
  })
  
  result <- callModule(
    module = esquisserServer,
    dataModule = "ImportFile",
    id = "esquisse",
    data = data_r
  )
  
  tmp_data = isolate(result$data)

  output$module_out <- renderPrint({
    str(reactiveValuesToList(result))
  })
  
}

shinyApp(ui, server)